@@ -6,7 +6,7 @@
 // [[Rcpp::export]]
 std::vector<double> vm_cpp(const double r, const double s, const std::vector<double>& dat_vec, const std::vector<double>& norm_gini, const std::vector<double>& w, const double sum_w) {
 	std::vector<double> vm(r * r, 0);
-	double agreement_sum = 0;
+	double agreement_sum = 0.0;
 	for (int i = 0; i < (r - 1); ++i) {
 		for (int j = (1 + i); j < r; ++j) {
 			for (int k = 0; k < s; ++k) {
@@ -15,13 +15,13 @@ std::vector<double> vm_cpp(const double r, const double s, const std::vector<dou
 				}
 			}
 			if (i == j) {
-				vm[i + (j * r)] = 0;
+				vm[i + (j * r)] = 0.0;
 			}
 			else {
-				vm[i + (j * r)] = (1 - (1 / sum_w * agreement_sum));
+				vm[i + (j * r)] = (1.0 - (1.0 / sum_w * agreement_sum));
 				vm[j + (i * r)] = vm[i + (j * r)];
 			}
-			agreement_sum = 0;
+			agreement_sum = 0.0;
 		}
 	}
 	return vm;
